@@ -1,6 +1,5 @@
 from dataclasses import dataclass
-from typing import Generic
-from typing import TypeVar
+from typing import Generic, TypeVar
 
 from myrabbit.commands.command_outcome import CommandOutcome
 from myrabbit.commands.reply_headers import CommandReplyHeaders
@@ -15,6 +14,9 @@ class CommandWithMessage(Generic[CommandType]):
     command: CommandType
     message: PikaMessage
 
+    def headers(self) -> dict:
+        return self.message.properties.headers
+
 
 @dataclass
 class ReplyWithMessage(Generic[CommandReplyType]):
@@ -32,3 +34,6 @@ class ReplyWithMessage(Generic[CommandReplyType]):
             CommandReplyHeaders.REPLY_OUTCOME
         ]
         return reply_outcome == CommandOutcome.FAILURE.name
+
+    def headers(self) -> dict:
+        return self.message.properties.headers
