@@ -1,6 +1,5 @@
 from dataclasses import dataclass
-from typing import Generic
-from typing import TypeVar
+from typing import Generic, TypeVar
 
 from myrabbit.core.consumer.pika_message import PikaMessage
 
@@ -11,3 +10,6 @@ EventType = TypeVar("EventType")
 class EventWithMessage(Generic[EventType]):
     event: EventType
     message: PikaMessage
+
+    def headers(self) -> dict:
+        return self.message.properties.headers
